@@ -24,6 +24,12 @@ class _Properties(StrEnum):
     PATH_MODULE_SCHEMA = 'path_module_schema'
     DDL_AUTO = 'ddl_auto'
     URL_CONNECTION = 'url_connection'
+    DB_PASSWORD = 'db_password'
+    DB_NAME = 'db_name'
+    DB_IP = 'db_ip'
+    DB_DRIVER = 'db_driver'
+    DB_PORT = 'db_port'
+    DB_USER = 'db_user'
 
 
 class _Groups(StrEnum):
